sections

package
v0.0.0-...-e1e991c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 12, 2022 License: Apache-2.0 Imports: 2 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewEntityList

func NewEntityList(tags []core.TagSlice) (entities.EntitySlice, error)

NewEntityList Parses a list of tag slices into entities. returns an EntitySlice.

Types

type Block

type Block struct {
	core.DxfParseable
	Name         string
	Handle       string
	LayerName    string
	SecondName   string
	BasePoint    core.Point
	XrefPathName string
	Description  string
	Entities     entities.EntitySlice
}

Block representation.

func NewBlock

func NewBlock(tags core.TagSlice) (*Block, error)

NewBlock builds a new Block from a slice of Tags.

func (Block) Equals

func (b Block) Equals(other core.DxfElement) bool

Equals compare with the other block for equality.

type BlocksSection

type BlocksSection map[string]*Block

BlocksSection BLOCKS section representation.

func NewBlocksSection

func NewBlocksSection(tags core.TagSlice) (BlocksSection, error)

NewBlocksSection creates a new BlocksSection from a slice of tags.

func (BlocksSection) Equals

func (b BlocksSection) Equals(other BlocksSection) bool

Equals Compare with the other BlocksSection for equality.

type EntitiesSection

type EntitiesSection struct {
	Entities entities.EntitySlice
}

EntitiesSection representation.

func NewEntitiesSection

func NewEntitiesSection(tags core.TagSlice) (*EntitiesSection, error)

NewEntitiesSection parses the EntitiesSection from a slice of tags.

func (EntitiesSection) Equals

func (e EntitiesSection) Equals(other core.DxfElement) bool

Equals Compare two EntitiesSection for equality

type HeaderSection

type HeaderSection struct {
	Values map[string]core.TagSlice
}

HeaderSection representation.

func NewHeaderSection

func NewHeaderSection(tags core.TagSlice) *HeaderSection

NewHeaderSection creates a new *HeaderSection from a core.TagSlice.

func (HeaderSection) Equals

func (section HeaderSection) Equals(other core.DxfElement) bool

Equals Compares two HeaderSections for equality. If other cannot be casted to a HeaderSection, returns false.

func (*HeaderSection) Get

func (section *HeaderSection) Get(key string) core.TagSlice

Get a slice of core.Tags by its key on the HeaderSection.

Jump to