Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SplitTagChunks ¶
func SplitTagChunks(tags core.TagSlice, stopTag *core.Tag, chunkDelimiter *core.Tag) []core.TagSlice
SplitTagChunks splits a TagSlice into a series of TagSlices delimited by chunkDelimiter tags. The Iteration ends at stopTag.
func TableEntryTags ¶
TableEntryTags splits a slice of tags that contains the TABLES entry of a DXF file, validates its basic structure and returns only the tags to be parsed as tables. (Removes the initial and final markup tags for table).
Types ¶
type AppID ¶
type AppID struct {
core.DxfParseable
Name string
}
AppID representation.
type Layer ¶
type Layer struct {
core.DxfParseable
Name string
Color int
LineType string
Locked bool
Frozen bool
On bool
}
Layer representation.
type LineElement ¶
type LineElement struct {
Length float64
AbsoluteRotation bool
IsTextString bool
IsShape bool
ShapeNumber int
Scale float64
RotationAngle float64
XOffset float64
YOffset float64
Text string
}
LineElement represents a single element in a LineType.
func (LineElement) Equals ¶
func (e LineElement) Equals(other LineElement) bool
Equals compares two LineElement objects for equality.
type LineType ¶
type LineType struct {
core.DxfParseable
Name string
Description string
Length float64
Pattern []*LineElement
}
LineType representation
func NewLineType ¶
NewLineType creates a new LineType object from a slice of tags.
type Style ¶
type Style struct {
core.DxfParseable
Name string
Height float64
Width float64
Oblique float64
IsBackwards bool
IsUpsideDown bool
IsShape bool
IsVerticalText bool
Font string
BigFont string
}
Style Table representation
type Table ¶
type Table map[string]core.DxfElement
Table representation.
func NewAppIDTable ¶
NewAppIDTable parses the slice of tags into a table that maps the AppID name to the parsed AppID object.
func NewLayerTable ¶
NewLayerTable parses the slice of tags into a table that maps the layer name to the parsed Layer object.
func NewLineTypeTable ¶
NewLineTypeTable parses the slice of tags into a table that maps the LineType name to the parsed LineType object.
func NewStyleTable ¶
NewStyleTable parses the slice of tags into a table that maps the Style name to the parsed Style object.
type TablesSection ¶
TablesSection representation
func NewTablesSection ¶
func NewTablesSection(tags core.TagSlice) (*TablesSection, error)
NewTablesSection parses the TablesSection from a slice of tags.
func (TablesSection) Equals ¶
func (t TablesSection) Equals(other core.DxfElement) bool
Equals Compare two TablesSection for equality